@@ -53,6 +53,8 @@ OpenAI::API::Request::Completion - completions endpoint
 
     my $res = $request->send();
 
+    my $text = $res->{choices}[0]{text};
+
 =head1 DESCRIPTION
 
 Given a prompt, the model will return one or more predicted completions.
@@ -129,6 +131,14 @@ C<max_tokens> and C<stop>.
 
 =back
 
+=head2 send()
+
+=head2 send($openai_config)
+
+Sends the request and returns a data structured similar to the one
+documented in the API reference.
+
+
 =head1 SEE ALSO
 
-OpenAI API Documentation: L<Completions|https://platform.openai.com/docs/api-reference/completions>
+OpenAI API Reference: L<Completions|https://platform.openai.com/docs/api-reference/completions>
